@@ -30,8 +30,6 @@ class BaseAPIView(APIView):
 
 
 class StandardAPIView(BaseAPIView):
-    pagination_class = CustomPagination
-
     def paginate_data(self, data, request, serializer_class=None, context=None, **kwargs):
         # Create a paginator instance
         paginator = self.pagination_class(**kwargs)
@@ -52,7 +50,8 @@ class StandardAPIView(BaseAPIView):
             'data': paginated_data,
         }
 
-        return APIResponseSerializer(response, context=context).data
+        # Return a Response object
+        return Response(APIResponseSerializer(response, context=context).data)
 
 
 # ============= Demo Views ============= #
